@@ -15,25 +15,27 @@ from contextchain.registry.version_manager import push_schema, list_versions, ro
 from contextchain.registry.schema_loader import load_schema
 from contextchain.db.mongo_client import get_mongo_client
 from contextchain.db.collections import setup_collections
+from contextchain.db.vector_db_client import ChromaClient
+from contextchain.local_llm_client import OllamaClient
+from contextchain.data_processing import chunk_text, summarize_text
+from contextchain.dag_builder import build_dag
+from contextchain.evaluation import evaluate_results
+from contextchain.task_registry import register_task
+import networkx as nx
+import chromadb
+import sentence_transformers
 from dotenv import load_dotenv
 import time
 import shutil
+import requests
 
-# New imports for updated features
-from contextchain.vector_db_client import ChromaClient  # New module for vector DB
-from contextchain.local_llm_client import OllamaClient  # New module for local LLM
-from contextchain.data_processing import chunk_text, summarize_text  # New module for data processing
-from contextchain.dag_builder import build_dag  # New module for DAG and parallelism
-from contextchain.evaluation import evaluate_results  # New module for evaluation
-from contextchain.task_registry import register_task  # New module for plugin architecture
-import networkx as nx  # For DAGs
-import chromadb  # For vector DB
-import sentence_transformers  # For embeddings
-# Note: Ollama is assumed to be installed and running externally; no direct import needed.
+# CLI Version
+VERSION = "1.1.3"
 
 # Load environment variables from .env file
 load_dotenv()
 logging.basicConfig(level=logging.INFO)
+logger = logging.getLogger(__name__)
 
 # Load colorama for better color support
 try:
@@ -52,7 +54,7 @@ def show_banner():
 ╚██████╗╚██████╔╝██║ ╚████║   ██║   ███████╗██╔╝ ██╗   ██║   
  ╚═════╝ ╚═════╝ ╚═╝  ╚═══╝   ╚═╝   ╚══════╝╚═╝  ╚═╝   ╚═╝   
                                                               
- ██████╗██╗  ██╗ █████╗ ██╗███╗   ██╗
+ ██████╗██╗  ██╗ █████╗ ██╗███╗   ██║
 ██╔════╝██║  ██║██╔══██╗██║████╗  ██║
 ██║     ███████║███████║██║██╔██╗ ██║
 ██║     ██╔══██║██╔══██║██║██║╚██╗██║
@@ -61,9 +63,9 @@ def show_banner():
     """
     click.secho("=" * 60, fg="bright_blue", bold=True)
     click.secho(ascii_art, fg="bright_blue", bold=True)
-    click.secho("         ContextChain v1.0 CLI", fg="bright_cyan", bold=True)
+    click.secho(f"         ContextChain v{VERSION} CLI", fg="bright_cyan", bold=True)
     click.secho("         Orchestrate AI and Full-Stack Workflows", fg="bright_cyan", bold=True)
-    click.secho("                        v1.0", fg="bright_white", bold=True)
+    click.secho(f"                        v{VERSION}", fg="bright_white", bold=True)
     click.secho("=" * 60, fg="bright_blue", bold=True)
 
 def update_current_schema(client, db_name, pipeline_id, version=None):
@@ -76,34 +78,23 @@ def update_current_schema(client, db_name, pipeline_id, version=None):
         meta = {
             "_meta": {
                 "pipeline_id": pipeline_id,
-                "version": schema.get("schema_version", "v0.0.0"),
+                "version": schema.get("schema_version", VERSION),
                 "timestamp": datetime.utcnow().isoformat() + "Z"
             },
             "schema": schema
         }
         try:
-            if not current_schema_path.exists():
-                with current_schema_path.open("w") as f:
-                    json.dump(meta, f, indent=2)
-                current_schema_path.chmod(stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP | stat.S_IROTH)
-            elif os.access(current_schema_path, os.W_OK):
-                with current_schema_path.open("w") as f:
-                    json.dump(meta, f, indent=2)
-                current_schema_path.chmod(stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP | stat.S_IROTH)
-            else:
-                click.secho(f"✗ current_schema.json for {pipeline_id} is read-only. Attempting to fix permissions...", fg="yellow", bold=True)
-                os.chmod(current_schema_path, stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP | stat.S_IROTH)
-                with current_schema_path.open("w") as f:
-                    json.dump(meta, f, indent=2)
+            with current_schema_path.open("w") as f:
+                json.dump(meta, f, indent=2)
+            current_schema_path.chmod(stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP | stat.S_IROTH)
+            click.secho(f"✓ Updated current_schema.json for {pipeline_id} (version: {schema.get('schema_version', VERSION)})", fg="bright_green", bold=True)
         except PermissionError:
-            click.secho(f"✗ Failed to update current_schema.json for {pipeline_id} due to permissions. Please run 'chmod u+w {current_schema_path}' manually.", fg="red", bold=True)
-            return
-        click.secho(f"✓ Updated current_schema.json for {pipeline_id} (version: {schema.get('schema_version', 'v0.0.0')})", fg="bright_green", bold=True)
+            click.secho(f"✗ Failed to update current_schema.json for {pipeline_id} due to permissions. Run 'chmod u+w {current_schema_path}' manually.", fg="red", bold=True)
     else:
         click.secho(f"✗ No schema found for {pipeline_id}", fg="red", bold=True)
 
 def copy_schema_file(pipeline_id, old_version, new_version):
-    """Create a backup copy of the schema file with a timestamp suffix without overwriting the original."""
+    """Create a backup copy of the schema file with a timestamp suffix."""
     source_path = Path(f"schemas/{pipeline_id}/{new_version}.json")
     if source_path.exists():
         timestamp = datetime.utcnow().strftime("%Y%m%d_%H%M%S")
@@ -120,7 +111,7 @@ class ColoredGroup(click.Group):
     def format_help(self, ctx, formatter):
         show_banner()
         click.secho("\nUsage: contextchain [OPTIONS] COMMAND [ARGS]...", fg="bright_white", bold=True)
-        click.secho("\nContextChain v1.0 CLI", fg="bright_cyan")
+        click.secho(f"\nContextChain v{VERSION} CLI", fg="bright_cyan")
 
         click.secho("\nOptions:", fg="bright_yellow", bold=True)
         click.secho("  -h, --help      Show this help message and exit.", fg="bright_cyan")
@@ -169,12 +160,8 @@ class ColoredGroup(click.Group):
         click.secho("\nNotes:", fg="bright_yellow", bold=True)
         click.secho("  - Use 'contextchain COMMAND --help' for detailed options of each command.", fg="bright_cyan")
 
-@click.group(cls=ColoredGroup, context_settings={"help_option_names": ["-h", "--help"]})
-def cli():
-    """ContextChain v1.0 CLI."""
-    pass
-
 def configure_task(i, interactive, allowed_task_types, tasks):
+    """Configure a single task interactively or with defaults."""
     click.secho(f"\nConfiguring Task {i+1}...", fg="bright_yellow", bold=True)
     if interactive:
         task_type = click.prompt(
@@ -190,7 +177,7 @@ def configure_task(i, interactive, allowed_task_types, tasks):
         "task_id": i + 1,
         "description": click.prompt(click.style(f"Task {i+1} description", fg="bright_blue"), default=f"Task {i+1}") if interactive else f"Task {i+1}",
         "task_type": task_type,
-        "endpoint": click.prompt(click.style(f"Task {i+1} endpoint", fg="bright_blue"), default="path.to.function") if interactive else "path.to.function",
+        "endpoint": click.prompt(click.style(f"Task {i+1} endpoint", fg="bright_blue"), default="contextchain.utils.default_task") if interactive else "contextchain.utils.default_task",
         "inputs": [],
         "input_source": None,
         "wait_for_input": False,
@@ -201,7 +188,7 @@ def configure_task(i, interactive, allowed_task_types, tasks):
         "rerun": None
     }
     
-    if task_type == "LLM" and interactive:
+    if task_type in ["LLM", "LLM_GENERATE"] and interactive:
         use_endpoint = click.confirm(click.style(f"Use a custom endpoint for Task {i+1} LLM (otherwise use global config)?", fg="bright_blue"), default=False)
         if use_endpoint:
             task["endpoint"] = click.prompt(click.style(f"Task {i+1} LLM endpoint (e.g., services.custom_llm.generate_summary)", fg="bright_blue"), default=task["endpoint"])
@@ -215,25 +202,36 @@ def configure_task(i, interactive, allowed_task_types, tasks):
             if click.confirm(click.style(f"Add inputs from other tasks?", fg="bright_blue"), default=False):
                 input_ids = click.prompt(click.style(f"Task {i+1} input task IDs (comma-separated)", fg="bright_blue"), default="")
                 task["inputs"] = [int(x.strip()) for x in input_ids.split(",") if x.strip()]
+    
     elif task_type == "LOCAL" and interactive:
         if click.confirm(click.style(f"Use trigger_logs for task {i+1}?", fg="bright_blue"), default=False):
             task["output_collection"] = "trigger_logs"
         if click.confirm(click.style(f"Add granularity for task {i+1}?", fg="bright_blue"), default=False):
-            granularity = click.prompt(click.style(f"Task {i+1} granularity (e.g., monthly, quarterly, or integer)", fg="bright_blue"), default="monthly")
-            task["parameters"]["granularity"] = granularity
+            task["parameters"]["granularity"] = click.prompt(click.style(f"Task {i+1} granularity (e.g., monthly, quarterly)", fg="bright_blue"), default="monthly")
     
-    if interactive and click.confirm(click.style(f"Add parameters for task {i+1}?", fg="bright_blue"), default=False):
+    elif task_type in ["VECTOR_STORE_ADD", "VECTOR_STORE_SEARCH"] and interactive:
+        task["parameters"]["collection_name"] = click.prompt(click.style(f"Task {i+1} vector DB collection name", fg="bright_blue"), default="default_collection")
+        if task_type == "VECTOR_STORE_SEARCH":
+            task["parameters"]["query"] = click.prompt(click.style(f"Task {i+1} search query", fg="bright_blue"), default="")
+    
+    elif task_type == "CHUNK_TEXT" and interactive:
+        task["parameters"]["max_length"] = click.prompt(click.style(f"Task {i+1} max chunk length", fg="bright_blue"), type=int, default=512)
+    
+    elif task_type == "EVALUATE" and interactive:
+        metrics = click.prompt(click.style(f"Task {i+1} metrics (comma-separated, e.g., mae,rmse)", fg="bright_blue"), default="")
+        task["parameters"]["metrics"] = [m.strip() for m in metrics.split(",") if m.strip()]
+    
+    elif task_type == "CUSTOM_ALERT" and interactive:
+        task["parameters"]["recipients"] = click.prompt(click.style(f"Task {i+1} alert recipients (comma-separated emails)", fg="bright_blue"), default="")
+    
+    if interactive and click.confirm(click.style(f"Add custom parameters for task {i+1}?", fg="bright_blue"), default=False):
         params_str = click.prompt(click.style(f"Task {i+1} parameters (YAML)", fg="bright_blue"), default="{}")
         try:
             params = yaml.safe_load(params_str)
             task["parameters"].update(params or {})
         except yaml.YAMLError:
-            click.secho("Invalid YAML, using empty parameters", fg="red")
+            click.secho("✗ Invalid YAML, using empty parameters", fg="red")
             task["parameters"] = {}
-        if "max_wait_seconds" not in task["parameters"] and click.confirm(click.style(f"Add max_wait_seconds for task {i+1}?", fg="bright_blue"), default=False):
-            task["parameters"]["max_wait_seconds"] = click.prompt(click.style("Max wait seconds", fg="bright_blue"), type=int, default=300)
-        if "timeout" not in task["parameters"] and click.confirm(click.style(f"Add timeout for task {i+1}?", fg="bright_blue"), default=False):
-            task["parameters"]["timeout"] = click.prompt(click.style("Task timeout (seconds)", fg="bright_blue"), type=int, default=30)
     
     if interactive and click.confirm(click.style(f"Add cron schedule for task {i+1}?", fg="bright_blue"), default=False):
         task["cron"] = click.prompt(click.style(f"Task {i+1} cron schedule", fg="bright_blue"), default="")
@@ -247,13 +245,18 @@ def configure_task(i, interactive, allowed_task_types, tasks):
     tasks.append(task)
     return tasks
 
+@click.group(cls=ColoredGroup, context_settings={"help_option_names": ["-h", "--help"]})
+def cli():
+    """ContextChain CLI."""
+    pass
+
 @cli.command()
-@click.option('--file', type=click.Path(), help='Output path for schema')
+@click.option('--file', type=click.Path(), help='Output path for schema (e.g., schemas/production.json)')
 @click.option('--interactive/--no-interactive', default=True, help='Enable interactive prompts')
 @click.option('--backend-host', default="http://127.0.0.1:8000", help='Backend host URL')
 @click.option('--frontend-host', default="http://127.0.0.1:3636", help='Frontend host URL')
 def init(file, interactive, backend_host, frontend_host):
-    """Initialize a new pipeline with a JSON schema and MongoDB setup."""
+    """Initialize a new pipeline with a JSON schema, MongoDB, and ChromaDB setup."""
     mongod_process = None
     show_banner()
     click.secho("\nInitializing New Pipeline...", fg="bright_yellow", bold=True)
@@ -270,6 +273,24 @@ def init(file, interactive, backend_host, frontend_host):
         tags = []
         pipeline_type = "fullstack-ai"
 
+    # Add sub-schemas support
+    sub_schemas = []
+    if interactive and click.confirm(click.style("Include sub-schemas in this pipeline?", fg="bright_blue"), default=False):
+        while click.confirm(click.style("Add a sub-schema?", fg="bright_blue"), default=True):
+            sub_schema_path = click.prompt(click.style("Path to sub-schema JSON file", fg="bright_blue"), default="")
+            sub_schema_path = Path(sub_schema_path)
+            if not sub_schema_path.is_file():
+                click.secho(f"✗ Sub-schema file not found: {sub_schema_path}. Please create it first.", fg="red", bold=True)
+                continue
+            try:
+                with sub_schema_path.open("r") as f:
+                    json.load(f)
+                sub_schemas.append(str(sub_schema_path))
+                click.secho(f"✓ Added sub-schema: {sub_schema_path}", fg="bright_green", bold=True)
+            except json.JSONDecodeError:
+                click.secho(f"✗ Invalid JSON in sub-schema file: {sub_schema_path}", fg="red", bold=True)
+                continue
+
     config = {}
     max_attempts = 3
     attempt = 1
@@ -277,6 +298,8 @@ def init(file, interactive, backend_host, frontend_host):
         mode = click.prompt(click.style(f"MongoDB mode (1: Default (local), 2: .ccshare) (attempt {attempt}/{max_attempts})", fg="bright_blue"), 
                            type=click.Choice(["1", "2"]), default="1") if interactive else "1"
         
+        config["db_name"] = click.prompt(click.style("MongoDB database name", fg="bright_blue"), default="blacklane-retail") if interactive else "blacklane-retail"
+        
         if mode == "2":
             ccshare_path = click.prompt(click.style("Path to .ccshare file", fg="bright_blue"), default="config/team.ccshare")
             try:
@@ -288,7 +311,6 @@ def init(file, interactive, backend_host, frontend_host):
                         return
                     continue
                 config["uri"] = ccshare["uri"]
-                config["db_name"] = ccshare.get("db_name", "contextchain_db")
                 config["ccshare_path"] = ccshare_path
             except FileNotFoundError:
                 click.secho(f"✗ File not found: {ccshare_path}", fg="red", bold=True)
@@ -301,24 +323,44 @@ def init(file, interactive, backend_host, frontend_host):
                     return
                 continue
         else:
-            config["uri"] = "mongodb://localhost:27017"
-            config["db_name"] = pipeline_id
+            config["uri"] = os.getenv("MONGO_URI", "mongodb://localhost:27017")
+
+        # ChromaDB configuration
+        config["chroma_path"] = click.prompt(click.style("ChromaDB storage path", fg="bright_blue"), default="./blacklane-optim") if interactive else "./blacklane-optim"
+        try:
+            os.makedirs(config["chroma_path"], exist_ok=True)
+            os.chmod(config["chroma_path"], 0o755)
+            ChromaClient(config["chroma_path"]).heartbeat()
+            click.secho(f"✓ Initialized ChromaDB at {config['chroma_path']}", fg="bright_green", bold=True)
+        except PermissionError:
+            click.secho(f"✗ Permission denied for ChromaDB path: {config['chroma_path']}. Run 'chmod -R u+w {config['chroma_path']}'", fg="red", bold=True)
+            if attempt == max_attempts:
+                return
+            attempt += 1
+            continue
+        except Exception as e:
+            click.secho(f"✗ Failed to initialize ChromaDB: {e}. Ensure chromadb is installed and path is valid.", fg="red", bold=True)
+            if attempt == max_attempts:
+                return
+            attempt += 1
+            continue
 
         config_path = Path("config/default_config.yaml")
         config_path.parent.mkdir(exist_ok=True)
         with config_path.open("w") as f:
             yaml.safe_dump(config, f)
+        os.chmod(config_path, stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP | stat.S_IROTH)
         
         click.secho("Setting up MongoDB connection...", fg="bright_yellow")
         try:
             client = get_mongo_client(config["uri"], db_name=config["db_name"])
             setup_collections(client, config["db_name"])
-            click.secho("MongoDB setup completed.", fg="bright_green", bold=True)
+            click.secho("✓ MongoDB setup completed.", fg="bright_green", bold=True)
             break
         except Exception as e:
             click.secho(f"✗ Failed to connect to MongoDB at {config['uri']}: {str(e)}", fg="red", bold=True)
             if attempt == max_attempts:
-                click.secho("✗ Max retry attempts reached. Please ensure MongoDB is installed and running, or use .ccshare mode.", fg="red", bold=True)
+                click.secho("✗ Max retry attempts reached. Please ensure MongoDB is installed and running.", fg="red", bold=True)
                 return
             attempt += 1
             if "mongodb://localhost" in config["uri"]:
@@ -343,7 +385,7 @@ def init(file, interactive, backend_host, frontend_host):
                             mongod_process.kill()
                     continue
 
-    if mongod_process and mongod_process.poll() is None and f"mongodb://localhost:27017" not in config["uri"]:
+    if mongod_process and mongod_process.poll() is None and "mongodb://localhost:27017" not in config["uri"]:
         mongod_process.terminate()
         try:
             mongod_process.wait(timeout=5)
@@ -353,6 +395,7 @@ def init(file, interactive, backend_host, frontend_host):
             click.secho("✓ Local MongoDB instance forcefully terminated.", fg="bright_green", bold=True)
 
     tasks = []
+    allowed_task_types = ["GET", "POST", "PUT", "LLM", "LLM_GENERATE", "LOCAL", "VECTOR_STORE_ADD", "VECTOR_STORE_SEARCH", "CHUNK_TEXT", "EVALUATE", "CUSTOM_ALERT"]
     if interactive:
         config_method = click.prompt(
             click.style("Configure tasks via (1: CLI, 2: Manual JSON Edit)", fg="bright_blue"),
@@ -361,42 +404,43 @@ def init(file, interactive, backend_host, frontend_host):
         )
         if config_method == "1":
             while True:
-                tasks = configure_task(len(tasks), interactive, ["GET", "POST", "PUT", "LLM", "LOCAL"], tasks)
+                tasks = configure_task(len(tasks), interactive, allowed_task_types, tasks)
                 if not click.confirm(click.style("Add another task?", fg="bright_blue"), default=False):
                     break
         else:
-            json_path = click.prompt(click.style("Path to JSON file for tasks", fg="bright_blue"), default="tasks.json")
-            schema_dir = Path(f"schemas/{pipeline_id}")
-            schema_dir.mkdir(parents=True, exist_ok=True)
-            full_path = schema_dir / json_path
-            if not full_path.exists():
-                default_tasks = [{"task_id": 1, "description": "Default Task", "task_type": "LOCAL", "endpoint": "path.to.function", "rerun": None}]
-                with full_path.open("w") as f:
+            json_path = click.prompt(click.style("Path to JSON file for schema", fg="bright_blue"), default=f"schemas/{pipeline_id}/{pipeline_id}.json")
+            json_path = Path(json_path)
+            if json_path.is_dir():
+                click.secho(f"✗ Provided path is a directory: {json_path}. Please specify a .json file.", fg="red", bold=True)
+                return
+            json_path.parent.mkdir(parents=True, exist_ok=True)
+            if not json_path.exists():
+                default_tasks = [{"task_id": 1, "description": "Default Task", "task_type": "LOCAL", "endpoint": "contextchain.utils.default_task", "rerun": None}]
+                with json_path.open("w") as f:
                     json.dump({"tasks": default_tasks}, f, indent=2)
-                click.secho(f"✓ Created default task file: {full_path}", fg="bright_green", bold=True)
+                click.secho(f"✓ Created default schema file: {json_path}", fg="bright_green", bold=True)
             try:
-                with full_path.open("r") as f:
+                with json_path.open("r") as f:
                     tasks_data = json.load(f)
                 tasks = tasks_data.get("tasks", [])
             except json.JSONDecodeError:
-                click.secho(f"✗ Invalid JSON format in {full_path}", fg="red", bold=True)
+                click.secho(f"✗ Invalid JSON format in {json_path}", fg="red", bold=True)
                 return
     else:
-        tasks = [configure_task(1, interactive, ["GET", "POST", "PUT", "LLM", "LOCAL"], [])[0]]
+        tasks = [configure_task(0, interactive, allowed_task_types, [])[0]]
 
     llm_config = {}
-    if any(task["task_type"] == "LLM" for task in tasks) and interactive:
-        if click.confirm(click.style("Configure LLM settings for this pipeline?", fg="bright_blue"), default=False):
-            llm_config["url"] = click.prompt(click.style("LLM API URL", fg="bright_blue"))
-            llm_config["api_key_env"] = click.prompt(click.style("Environment variable for API key", fg="bright_blue"), default="OPENROUTER_API_KEY")
+    if any(task["task_type"] in ["LLM", "LLM_GENERATE"] for task in tasks) and interactive:
+        if click.confirm(click.style("Configure LLM settings for this pipeline?", fg="bright_blue"), default=True):
+            llm_config["provider"] = click.prompt(click.style("LLM provider (e.g., ollama)", fg="bright_blue"), default="ollama")
+            llm_config["model"] = click.prompt(click.style("LLM model (e.g., mistral:7b)", fg="bright_blue"), default="mistral:7b")
+            llm_config["url"] = click.prompt(click.style("LLM API URL (optional)", fg="bright_blue"), default="http://localhost:11434")
+            llm_config["api_key_env"] = click.prompt(click.style("Environment variable for API key", fg="bright_blue"), default="")
             llm_config["api_key"] = click.prompt(click.style("Direct API key (optional)", fg="bright_blue"), default="") if not llm_config["api_key_env"] else ""
-            llm_config["model"] = click.prompt(click.style("LLM model", fg="bright_blue"))
-            llm_config["referer"] = click.prompt(click.style("Referer URL", fg="bright_blue"), default="http://your-site-url.com")
-            llm_config["title"] = click.prompt(click.style("X-Title", fg="bright_blue"), default="Your Site Name")
 
     schema = {
         "pipeline_id": pipeline_id,
-        "schema_version": "v0.1.0",
+        "schema_version": VERSION,
         "description": description,
         "created_by": created_by,
         "created_at": datetime.utcnow().isoformat() + "Z",
@@ -406,21 +450,23 @@ def init(file, interactive, backend_host, frontend_host):
             "logging_level": "INFO",
             "retry_on_failure": True,
             "max_retries": 2,
-            "allowed_task_types": ["GET", "POST", "PUT", "LLM", "LOCAL"],
+            "allowed_task_types": allowed_task_types,
             "allowed_domains": [],
             "backend_host": backend_host,
             "frontend_host": frontend_host,
-            "llm_config": llm_config if llm_config else {}
+            "llm_config": llm_config,
+            "vector_db_config": {"type": "chroma", "path": config["chroma_path"]}
         },
         "metadata": {
             "tags": tags,
             "pipeline_type": pipeline_type,
             "linked_pipelines": [],
             "status": "draft",
-            "parent_version": None
+            "parent_version": None,
+            "sub_schemas": sub_schemas
         }
     }
-    
+
     if interactive and click.confirm(click.style("Configure advanced settings?", fg="bright_blue"), default=False):
         logging_level = click.prompt(click.style("Logging level", fg="bright_blue"), default="INFO", type=click.Choice(["INFO", "DEBUG", "WARNING", "ERROR"]))
         retry_on_failure = click.confirm(click.style("Retry on failure?", fg="bright_blue"), default=True)
@@ -449,14 +495,29 @@ def init(file, interactive, backend_host, frontend_host):
         click.secho(f"✗ Push error: {e}", fg="red", bold=True)
         return
 
-    schema_dir = Path(f"schemas/{pipeline_id}")
+    schema_dir = Path(file).parent if file else Path(f"schemas/{pipeline_id}")
     schema_dir.mkdir(parents=True, exist_ok=True)
-    schema_path = Path(file) if file else schema_dir / f"v0.1.0.json"
+    schema_path = Path(file) if file else schema_dir / f"{pipeline_id}.json"
+    if schema_path.is_dir():
+        click.secho(f"✗ Schema path is a directory: {schema_path}. Please specify a .json file.", fg="red", bold=True)
+        return
     with schema_path.open("w") as f:
         json.dump(schema, f, indent=2)
     schema_path.chmod(stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP | stat.S_IROTH)
     click.secho(f"✓ Pipeline initialized: {schema_path}", fg="bright_green", bold=True)
 
+    # Validate and push sub-schemas
+    for sub_schema_path in sub_schemas:
+        try:
+            with open(sub_schema_path, 'r') as f:
+                sub_schema = json.load(f)
+            sub_schema["metadata"]["parent_pipeline_id"] = pipeline_id
+            validate_schema(sub_schema, is_initial=True)
+            push_schema(client, db_name, sub_schema, is_initial=True)
+            click.secho(f"✓ Sub-schema {sub_schema['pipeline_id']} pushed to MongoDB.", fg="bright_green", bold=True)
+        except Exception as e:
+            click.secho(f"✗ Error pushing sub-schema {sub_schema_path}: {e}", fg="red", bold=True)
+
 @cli.command()
 @click.option('--pipeline-id', required=True, help='Pipeline ID')
 def new_version(pipeline_id):
@@ -672,7 +733,7 @@ def ccshare_init():
     click.secho("\nInitializing .ccshare File...", fg="bright_yellow", bold=True)
     ccshare = {
         "uri": click.prompt(click.style("MongoDB Atlas URI", fg="bright_blue"), default="mongodb+srv://user:pass@cluster0.mongodb.net"),
-        "db_name": click.prompt(click.style("Database name", fg="bright_blue"), default="contextchain_db"),
+        "db_name": click.prompt(click.style("Database name", fg="bright_blue"), default="blacklane-retail"),
         "roles": []
     }
     while click.confirm(click.style("Add a user role?", fg="bright_blue")):
@@ -683,6 +744,7 @@ def ccshare_init():
     output_path.parent.mkdir(exist_ok=True)
     with output_path.open("w") as f:
         yaml.safe_dump(ccshare, f)
+    os.chmod(output_path, stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP | stat.S_IROTH)
     click.secho(f"✓ .ccshare file created: {output_path}", fg="bright_green", bold=True)
 
 @cli.command()
@@ -692,7 +754,7 @@ def ccshare_join(uri):
     click.secho("\nJoining .ccshare Collaboration...", fg="bright_yellow", bold=True)
     ccshare = {
         "uri": uri,
-        "db_name": click.prompt(click.style("Database name", fg="bright_blue"), default="contextchain_db"),
+        "db_name": click.prompt(click.style("Database name", fg="bright_blue"), default="blacklane-retail"),
         "roles": [{
             "user": click.prompt(click.style("Username", fg="bright_blue")), 
             "role": click.prompt(click.style("Role", fg="bright_blue"), default="readOnly", type=click.Choice(["readOnly", "readWrite"]))
@@ -702,6 +764,7 @@ def ccshare_join(uri):
     output_path.parent.mkdir(exist_ok=True)
     with output_path.open("w") as f:
         yaml.safe_dump(ccshare, f)
+    os.chmod(output_path, stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP | stat.S_IROTH)
     click.secho(f"✓ Joined collaboration: {output_path}", fg="bright_green", bold=True)
 
 @cli.command()
@@ -817,8 +880,6 @@ def list_pipelines():
         click.secho(f"✗ Error: {e}", fg="red", bold=True)
         return
 
-# New CLI Groups and Commands
-
 @cli.group()
 def vector():
     """Vector DB operations."""
@@ -830,7 +891,10 @@ def init(collection):
     """Initialize a vector DB collection."""
     click.secho(f"\nInitializing Vector DB Collection {collection}...", fg="bright_yellow", bold=True)
     try:
-        client = ChromaClient()  # Assuming default path from config
+        config_path = Path("config/default_config.yaml")
+        with config_path.open("r") as f:
+            config = yaml.safe_load(f)
+        client = ChromaClient(config.get("chroma_path", "./blacklane-optim"))
         client.create_collection(collection)
         click.secho(f"✓ Vector DB collection {collection} initialized.", fg="bright_green", bold=True)
     except Exception as e:
@@ -843,7 +907,10 @@ def search(collection, query):
     """Search in a vector DB collection."""
     click.secho(f"\nSearching in Vector DB Collection {collection}...", fg="bright_yellow", bold=True)
     try:
-        client = ChromaClient()
+        config_path = Path("config/default_config.yaml")
+        with config_path.open("r") as f:
+            config = yaml.safe_load(f)
+        client = ChromaClient(config.get("chroma_path", "./blacklane-optim"))
         results = client.search(collection, query)
         click.secho(f"Results: {results}", fg="bright_green", bold=True)
     except Exception as e:
@@ -855,14 +922,26 @@ def llm():
     pass
 
 @llm.command()
-@click.option('--model', required=True, help='LLM model name')
+@click.option('--model', required=True, help='LLM model name (e.g., mistral:7b)')
 def setup(model):
     """Setup a local LLM model."""
     click.secho(f"\nSetting up LLM Model {model}...", fg="bright_yellow", bold=True)
     try:
-        client = OllamaClient(model=model)
-        client.setup()  # Pull and initialize model
+        # Check if Ollama server is running
+        response = requests.get("http://localhost:11434")
+        if response.status_code != 200:
+            click.secho("✗ Ollama server not running. Start it with 'ollama run mistral:7b' in a separate terminal.", fg="red", bold=True)
+            return
+        # Check if model is pulled
+        result = subprocess.run(["ollama", "list"], capture_output=True, text=True)
+        if model not in result.stdout:
+            click.secho(f"Pulling model {model}...", fg="bright_yellow")
+            subprocess.run(["ollama", "pull", model], check=True)
         click.secho(f"✓ LLM model {model} setup completed.", fg="bright_green", bold=True)
+    except subprocess.CalledProcessError:
+        click.secho(f"✗ Failed to pull model {model}. Ensure Ollama is installed and accessible.", fg="red", bold=True)
+    except requests.RequestException:
+        click.secho("✗ Ollama server not running. Start it with 'ollama run mistral:7b' in a separate terminal.", fg="red", bold=True)
     except Exception as e:
         click.secho(f"✗ Error: {e}", fg="red", bold=True)
 
@@ -904,6 +983,27 @@ def evaluate(task_id):
     except Exception as e:
         click.secho(f"✗ Error: {e}", fg="red", bold=True)
 
+@cli.command()
+@click.option('--pipeline_id', required=True, help='Pipeline ID')
+def schema_current(pipeline_id):
+    """Display the current schema version."""
+    click.secho(f"\nDisplaying Current Schema for Pipeline {pipeline_id}...", fg="bright_yellow", bold=True)
+    try:
+        config_path = Path("config/default_config.yaml")
+        with config_path.open("r") as f:
+            config = yaml.safe_load(f)
+        client = get_mongo_client(config["uri"])
+        db_name = config["db_name"]
+        schema = load_schema(client, db_name, pipeline_id)
+        if schema:
+            click.secho(f"Current version: {schema['schema_version']}", fg="bright_green")
+            click.secho(f"Created at: {schema['created_at']}", fg="bright_cyan")
+            click.secho(f"Description: {schema['description']}", fg="bright_cyan")
+        else:
+            click.secho(f"✗ Schema {pipeline_id} not found.", fg="red", bold=True)
+    except Exception as e:
+        click.secho(f"✗ Error: {e}", fg="red", bold=True)
+
 @cli.group()
 def plugin():
     """Manage plugins."""
